@@ -14,9 +14,18 @@
 
 error_reporting(E_ALL | E_STRICT);
 
-if (is_file(dirname(__FILE__).'/../CodeSniffer.php') === true) {
-    include_once dirname(__FILE__).'/../CodeSniffer.php';
+// Installations via Composer: make sure that we autoload all dependencies.
+if (file_exists($a = dirname(__FILE__).'/../../../autoload.php') === true) {
+    include_once $a;
+} else if (file_exists($a = dirname(__FILE__).'/../vendor/autoload.php') === true) {
+    include_once $a;
+}
+
+if (file_exists($a = dirname(__FILE__).'/../CodeSniffer.php') === true) {
+    // Running from a git clone.
+    include_once $a;
 } else {
+    // PEAR installed.
     include_once 'PHP/CodeSniffer.php';
 }
 
@@ -28,7 +37,7 @@ if (is_file(dirname(__FILE__).'/../CodeSniffer.php') === true) {
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_CLI
@@ -273,6 +282,7 @@ class PHP_CodeSniffer_CLI
         $defaults['reportFile']      = null;
         $defaults['generator']       = '';
         $defaults['reports']         = array();
+        $defaults['bootstrap']       = array();
         $defaults['errorSeverity']   = null;
         $defaults['warningSeverity'] = null;
 
@@ -600,37 +610,49 @@ class PHP_CodeSniffer_CLI
                 }
 
                 $this->values['sniffs'] = $sniffs;
+            } else if (substr($arg, 0, 10) === 'bootstrap=') {
+                $files = explode(',', substr($arg, 10));
+                foreach ($files as $file) {
+                    $path = PHP_CodeSniffer::realpath($file);
+                    if ($path === false) {
+                        echo 'ERROR: The specified bootstrap file "'.$file.'" does not exist'.PHP_EOL.PHP_EOL;
+                        $this->printUsage();
+                        exit(2);
+                    }
+
+                    $this->values['bootstrap'][] = $path;
+                }
             } else if (substr($arg, 0, 12) === 'report-file=') {
                 $this->values['reportFile'] = PHP_CodeSniffer::realpath(substr($arg, 12));
 
                 // It may not exist and return false instead.
                 if ($this->values['reportFile'] === false) {
                     $this->values['reportFile'] = substr($arg, 12);
-                }
+
+                    $dir = dirname($this->values['reportFile']);
+                    if (is_dir($dir) === false) {
+                        echo 'ERROR: The specified report file path "'.$this->values['reportFile'].'" points to a non-existent directory'.PHP_EOL.PHP_EOL;
+                        $this->printUsage();
+                        exit(2);
+                    }
+
+                    if ($dir === '.') {
+                        // Passed report file is a file in the current directory.
+                        $this->values['reportFile'] = getcwd().'/'.basename($this->values['reportFile']);
+                    } else {
+                        $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
+                        if ($dir !== false) {
+                            // Report file path is relative.
+                            $this->values['reportFile'] = $dir.'/'.basename($this->values['reportFile']);
+                        }
+                    }
+                }//end if
 
                 if (is_dir($this->values['reportFile']) === true) {
                     echo 'ERROR: The specified report file path "'.$this->values['reportFile'].'" is a directory'.PHP_EOL.PHP_EOL;
                     $this->printUsage();
                     exit(2);
                 }
-
-                $dir = dirname($this->values['reportFile']);
-                if (is_dir($dir) === false) {
-                    echo 'ERROR: The specified report file path "'.$this->values['reportFile'].'" points to a non-existent directory'.PHP_EOL.PHP_EOL;
-                    $this->printUsage();
-                    exit(2);
-                }
-
-                if ($dir === '.') {
-                    // Passed report file is a filename in the current directory.
-                    $this->values['reportFile'] = getcwd().'/'.basename($this->values['reportFile']);
-                } else {
-                    $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
-                    if ($dir !== false) {
-                        // Report file path is relative.
-                        $this->values['reportFile'] = $dir.'/'.basename($this->values['reportFile']);
-                    }
-                }
             } else if (substr($arg, 0, 13) === 'report-width=') {
                 $this->values['reportWidth'] = $this->_validateReportWidth(substr($arg, 13));
             } else if (substr($arg, 0, 7) === 'report='
@@ -782,6 +804,10 @@ class PHP_CodeSniffer_CLI
 
         if ($values['generator'] !== '') {
             $phpcs = new PHP_CodeSniffer($values['verbosity']);
+            if ($values['standard'] === null) {
+                $values['standard'] = $this->validateStandard(null);
+            }
+
             foreach ($values['standard'] as $standard) {
                 $phpcs->generateDocs(
                     $standard,
@@ -852,6 +878,11 @@ class PHP_CodeSniffer_CLI
             $this->values['reports']   = $values['reports'];
         }
 
+        // Include bootstrap files.
+        foreach ($values['bootstrap'] as $bootstrap) {
+            include $bootstrap;
+        }
+
         $phpcs->processFiles($values['files'], $values['local']);
 
         if (empty($values['files']) === true) {
@@ -995,13 +1026,23 @@ class PHP_CodeSniffer_CLI
     {
         if ($standards === null) {
             // They did not supply a standard to use.
-            // Looks for a ruleset in the current directory.
-            if (empty($this->values['files']) === true) {
-                $default = getcwd().DIRECTORY_SEPARATOR.'phpcs.xml';
+            // Look for a default ruleset in the current directory or higher.
+            $currentDir = getcwd();
+
+            do {
+                $default = $currentDir.DIRECTORY_SEPARATOR.'phpcs.xml';
                 if (is_file($default) === true) {
                     return array($default);
                 }
-            }
+
+                $default = $currentDir.DIRECTORY_SEPARATOR.'phpcs.xml.dist';
+                if (is_file($default) === true) {
+                    return array($default);
+                }
+
+                $lastDir    = $currentDir;
+                $currentDir = dirname($currentDir);
+            } while ($currentDir !== '.' && $currentDir !== $lastDir);
 
             // Try to get the default from the config system.
             $standard = PHP_CodeSniffer::getConfigData('default_standard');
@@ -1011,7 +1052,7 @@ class PHP_CodeSniffer_CLI
             }
 
             return array($standard);
-        }
+        }//end if
 
         $cleaned   = array();
         $standards = (array) $standards;
@@ -1150,7 +1191,7 @@ class PHP_CodeSniffer_CLI
         echo '    [--severity=<severity>] [--error-severity=<severity>] [--warning-severity=<severity>]'.PHP_EOL;
         echo '    [--runtime-set key value] [--config-set key value] [--config-delete key] [--config-show]'.PHP_EOL;
         echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--encoding=<encoding>]'.PHP_EOL;
-        echo '    [--extensions=<extensions>] [--ignore=<patterns>] <file> ...'.PHP_EOL;
+        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>] <file> ...'.PHP_EOL;
         echo '                      Set runtime value (see --config-set) '.PHP_EOL;
         echo '        -n            Do not print warnings (shortcut for --warning-severity=0)'.PHP_EOL;
         echo '        -w            Print both warnings and errors (this is the default)'.PHP_EOL;
@@ -1167,13 +1208,14 @@ class PHP_CodeSniffer_CLI
         echo '        --colors      Use colors in output'.PHP_EOL;
         echo '        --no-colors   Do not use colors in output (this is the default)'.PHP_EOL;
         echo '        <file>        One or more files and/or directories to check'.PHP_EOL;
+        echo '        <bootstrap>   A comma separated list of files to run before processing starts'.PHP_EOL;
         echo '        <encoding>    The encoding of the files being checked (default is iso-8859-1)'.PHP_EOL;
         echo '        <extensions>  A comma separated list of file extensions to check'.PHP_EOL;
         echo '                      (extension filtering only valid when checking a directory)'.PHP_EOL;
         echo '                      The type of the file can be specified using: ext/type'.PHP_EOL;
         echo '                      e.g., module/php,es/js'.PHP_EOL;
-        echo '        <generator>   The name of a doc generator to use'.PHP_EOL;
-        echo '                      (forces doc generation instead of checking)'.PHP_EOL;
+        echo '        <generator>   Uses either the "HMTL", "Markdown" or "Text" generator'.PHP_EOL;
+        echo '                      (forces documentation generation instead of checking)'.PHP_EOL;
         echo '        <patterns>    A comma separated list of patterns to ignore files and directories'.PHP_EOL;
         echo '        <report>      Print either the "full", "xml", "checkstyle", "csv"'.PHP_EOL;
         echo '                      "json", "emacs", "source", "summary", "diff"'.PHP_EOL;
@@ -1202,7 +1244,7 @@ class PHP_CodeSniffer_CLI
         echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--suffix=<suffix>]'.PHP_EOL;
         echo '    [--severity=<severity>] [--error-severity=<severity>] [--warning-severity=<severity>]'.PHP_EOL;
         echo '    [--tab-width=<tabWidth>] [--encoding=<encoding>]'.PHP_EOL;
-        echo '    [--extensions=<extensions>] [--ignore=<patterns>] <file> ...'.PHP_EOL;
+        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>] <file> ...'.PHP_EOL;
         echo '        -n            Do not fix warnings (shortcut for --warning-severity=0)'.PHP_EOL;
         echo '        -w            Fix both warnings and errors (on by default)'.PHP_EOL;
         echo '        -l            Local directory only, no recursion'.PHP_EOL;
@@ -1212,6 +1254,7 @@ class PHP_CodeSniffer_CLI
         echo '        --version     Print version information'.PHP_EOL;
         echo '        --no-patch    Do not make use of the "diff" or "patch" programs'.PHP_EOL;
         echo '        <file>        One or more files and/or directories to fix'.PHP_EOL;
+        echo '        <bootstrap>   A comma separated list of files to run before processing starts'.PHP_EOL;
         echo '        <encoding>    The encoding of the files being fixed (default is iso-8859-1)'.PHP_EOL;
         echo '        <extensions>  A comma separated list of file extensions to fix'.PHP_EOL;
         echo '                      (extension filtering only valid when checking a directory)'.PHP_EOL;
