@@ -23,7 +23,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2012 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Fixer
@@ -499,7 +499,9 @@ class PHP_CodeSniffer_Fixer
                                                  'loop' => $this->loops,
                                                 );
         } else {
-            if ($this->_oldTokenValues[$stackPtr]['prev'] === $content) {
+            if ($this->_oldTokenValues[$stackPtr]['prev'] === $content
+                && $this->_oldTokenValues[$stackPtr]['loop'] === ($this->loops - 1)
+            ) {
                 if (PHP_CODESNIFFER_VERBOSITY > 1) {
                     $indent = "\t";
                     if (empty($this->_changeset) === false) {
