@@ -26,7 +26,7 @@
  * @copyright 2009-2014 SQLI <www.sqli.com>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
@@ -177,9 +177,15 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
         echo "\033[0m".str_repeat('-', $width).PHP_EOL;
 
         $fixableSources = 0;
-        $maxSniffWidth  = 37;
+
+        if ($showSources === true) {
+            $maxSniffWidth = ($width - 7);
+        } else {
+            $maxSniffWidth = ($width - 37);
+        }
+
         if ($totalFixable > 0) {
-            $maxSniffWidth += 4;
+            $maxSniffWidth -= 4;
         }
 
         foreach ($this->_sourceCache as $source => $sourceData) {
@@ -196,6 +202,10 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
             }
 
             if ($showSources === true) {
+                if ($sourceData['strlen'] > $maxSniffWidth) {
+                    $source = substr($source, 0, $maxSniffWidth);
+                }
+
                 echo $source;
                 if ($totalFixable > 0) {
                     echo str_repeat(' ', ($width - 9 - strlen($source)));
@@ -219,8 +229,8 @@ class PHP_CodeSniffer_Reports_Source implements PHP_CodeSniffer_Report
                 echo $category.str_repeat(' ', (20 - strlen($category)));
 
                 $sniff = $parts[2];
-                if (strlen($sniff) > ($width - $maxSniffWidth)) {
-                    $sniff = substr($sniff, 0, ($width - $maxSniffWidth - strlen($sniff)));
+                if (strlen($sniff) > $maxSniffWidth) {
+                    $sniff = substr($sniff, 0, $maxSniffWidth);
                 }
 
                 if ($totalFixable > 0) {
