@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_ControlStructures_InlineControlStructureSniff implements PHP_CodeSniffer_Sniff
@@ -58,6 +58,7 @@ class Generic_Sniffs_ControlStructures_InlineControlStructureSniff implements PH
         return array(
                 T_IF,
                 T_ELSE,
+                T_ELSEIF,
                 T_FOREACH,
                 T_WHILE,
                 T_DO,
@@ -106,7 +107,22 @@ class Generic_Sniffs_ControlStructures_InlineControlStructureSniff implements PH
                     }
                 }
             }
-        }
+
+            // In Javascript DO WHILE loops without curly braces are legal. This
+            // is only valid if a single statement is present between the DO and
+            // the WHILE. We can detect this by checking only a single semicolon
+            // is present between them.
+            if ($phpcsFile->tokenizerType === 'JS') {
+                $lastDo        = $phpcsFile->findPrevious(T_DO, ($stackPtr - 1));
+                $lastSemicolon = $phpcsFile->findPrevious(T_SEMICOLON, ($stackPtr - 1));
+                if ($lastDo !== false && $lastSemicolon !== false && $lastDo < $lastSemicolon) {
+                    $precedingSemicolon = $phpcsFile->findPrevious(T_SEMICOLON, ($lastSemicolon - 1));
+                    if ($precedingSemicolon === false || $precedingSemicolon < $lastDo) {
+                        return;
+                    }
+                }
+            }
+        }//end if
 
         // This is a control structure without an opening brace,
         // so it is an inline statement.
@@ -146,14 +162,38 @@ class Generic_Sniffs_ControlStructures_InlineControlStructureSniff implements PH
                 }
 
                 if (isset($tokens[$end]['scope_opener']) === true) {
-                    $end = $tokens[$end]['scope_closer'];
+                    $type = $tokens[$end]['code'];
+                    $end  = $tokens[$end]['scope_closer'];
+                    if ($type === T_DO || $type === T_IF || $type === T_ELSEIF) {
+                        $next = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($end + 1), null, true);
+                        if ($next === false) {
+                            break;
+                        }
+
+                        $nextType = $tokens[$next]['code'];
+
+                        // Let additional conditions loop and find their ending.
+                        if (($type === T_IF
+                            || $type === T_ELSEIF)
+                            && ($nextType === T_ELSEIF
+                            || $nextType === T_ELSE)
+                        ) {
+                            continue;
+                        }
+
+                        // Account for DO... WHILE conditions.
+                        if ($type === T_DO && $nextType === T_WHILE) {
+                            $end = $phpcsFile->findNext(T_SEMICOLON, ($next + 1));
+                        }
+                    }//end if
+
                     break;
-                }
+                }//end if
 
                 if ($tokens[$end]['code'] !== T_WHITESPACE) {
                     $lastNonEmpty = $end;
                 }
-            }
+            }//end for
 
             $next = $phpcsFile->findNext(T_WHITESPACE, ($closer + 1), ($end + 1), true);
 
