@@ -20,7 +20,7 @@
  * @author    Andy Grunwald <andygrunwald@gmail.com>
  * @copyright 2010-2014 Andy Grunwald
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Files_LowercasedFilenameSniff implements PHP_CodeSniffer_Sniff
@@ -50,12 +50,17 @@ class Generic_Sniffs_Files_LowercasedFilenameSniff implements PHP_CodeSniffer_Sn
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        $fileName          = basename($phpcsFile->getFilename());
-        $lowercaseFileName = strtolower($fileName);
-        if ($fileName !== $lowercaseFileName) {
+        $filename = $phpcsFile->getFilename();
+        if ($filename === 'STDIN') {
+            return;
+        }
+
+        $filename          = basename($filename);
+        $lowercaseFilename = strtolower($filename);
+        if ($filename !== $lowercaseFilename) {
             $data  = array(
-                      $fileName,
-                      $lowercaseFileName,
+                      $filename,
+                      $lowercaseFilename,
                      );
             $error = 'Filename "%s" doesn\'t match the expected filename "%s"';
             $phpcsFile->addError($error, $stackPtr, 'NotFound', $data);
