@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Functions_OpeningFunctionBraceBsdAllmanSniff implements PHP_CodeSniffer_Sniff
@@ -155,16 +155,7 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceBsdAllmanSniff implements PHP
         // as if this is a method with tokens before it (public, static etc)
         // or an if with an else before it, then we need to start the scope
         // checking from there, rather than the current token.
-        $lineStart = $stackPtr;
-        while (($lineStart = $phpcsFile->findPrevious(T_WHITESPACE, ($lineStart - 1), null, false)) !== false) {
-            if (strpos($tokens[$lineStart]['content'], $phpcsFile->eolChar) !== false) {
-                break;
-            }
-        }
-
-        // We found a new line, now go forward and find the first
-        // non-whitespace token.
-        $lineStart = $phpcsFile->findNext(T_WHITESPACE, $lineStart, null, true);
+        $lineStart = $phpcsFile->findFirstOnLine(T_WHITESPACE, $stackPtr, true);
 
         // The opening brace is on the correct line, now it needs to be
         // checked to be correctly indented.
