@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Sniff
@@ -141,6 +141,11 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
+        $debug = PHP_CodeSniffer::getConfigData('scope_indent_debug');
+        if ($debug !== null) {
+            $this->_debug = (bool) $debug;
+        }
+
         if ($this->_tabWidth === null) {
             $cliValues = $phpcsFile->phpcs->cli->getCommandLineValues();
             if (isset($cliValues['tabWidth']) === false || $cliValues['tabWidth'] === 0) {
@@ -159,8 +164,19 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
         $openScopes    = array();
         $adjustments   = array();
 
-        $tokens        = $phpcsFile->getTokens();
-        $currentIndent = ($tokens[$stackPtr]['column'] - 1);
+        $tokens  = $phpcsFile->getTokens();
+        $first   = $phpcsFile->findFirstOnLine(T_INLINE_HTML, $stackPtr);
+        $trimmed = ltrim($tokens[$first]['content']);
+        if ($trimmed === '') {
+            $currentIndent = ($tokens[$stackPtr]['column'] - 1);
+        } else {
+            $currentIndent = (strlen($tokens[$first]['content']) - strlen($trimmed));
+        }
+
+        if ($this->_debug === true) {
+            $line = $tokens[$stackPtr]['line'];
+            echo "Start with token $stackPtr on line $line with indent $currentIndent".PHP_EOL;
+        }
 
         if (empty($this->_ignoreIndentationTokens) === true) {
             $this->_ignoreIndentationTokens = array(T_INLINE_HTML => true);
@@ -215,113 +231,190 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
 
             // Closing parenthesis should just be indented to at least
             // the same level as where they were opened (but can be more).
-            if ($checkToken !== null
+            if (($checkToken !== null
                 && $tokens[$checkToken]['code'] === T_CLOSE_PARENTHESIS
-                && isset($tokens[$checkToken]['parenthesis_opener']) === true
+                && isset($tokens[$checkToken]['parenthesis_opener']) === true)
+                || ($tokens[$i]['code'] === T_CLOSE_PARENTHESIS
+                && isset($tokens[$i]['parenthesis_opener']) === true
+                && isset($tokens[$i]['parenthesis_owner']) === true
+                && $tokens[$tokens[$i]['parenthesis_owner']]['code'] === T_ARRAY)
             ) {
+                if ($checkToken !== null) {
+                    $parenCloser = $checkToken;
+                } else {
+                    $parenCloser = $i;
+                }
+
                 if ($this->_debug === true) {
                     $line = $tokens[$i]['line'];
                     echo "Closing parenthesis found on line $line".PHP_EOL;
                 }
 
-                $first       = $phpcsFile->findFirstOnLine(T_WHITESPACE, $tokens[$checkToken]['parenthesis_opener'], true);
-                $checkIndent = ($tokens[$first]['column'] - 1);
-                if (isset($adjustments[$first]) === true) {
-                    $checkIndent += $adjustments[$first];
-                }
-
-                $exact = false;
-
-                if ($this->_debug === true) {
-                    $line = $tokens[$first]['line'];
-                    $type = $tokens[$first]['type'];
-                    echo "\t* first token on line $line is $type *".PHP_EOL;
-                }
-
-                $prev = $phpcsFile->findStartOfStatement($first);
-                if ($prev !== $first) {
-                    // This is not the start of the statement.
-                    if ($this->_debug === true) {
-                        $line = $tokens[$prev]['line'];
-                        $type = $tokens[$prev]['type'];
-                        echo "\t* previous is $type on line $line *".PHP_EOL;
+                $parenOpener = $tokens[$parenCloser]['parenthesis_opener'];
+                if ($tokens[$parenCloser]['line'] !== $tokens[$parenOpener]['line']) {
+                    $first       = $phpcsFile->findFirstOnLine(T_WHITESPACE, $parenOpener, true);
+                    $checkIndent = ($tokens[$first]['column'] - 1);
+                    if (isset($adjustments[$first]) === true) {
+                        $checkIndent += $adjustments[$first];
                     }
 
-                    $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
-                    $prev  = $phpcsFile->findStartOfStatement($first);
-                    $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                    $exact = false;
+
                     if ($this->_debug === true) {
                         $line = $tokens[$first]['line'];
                         $type = $tokens[$first]['type'];
-                        echo "\t* amended first token is $type on line $line *".PHP_EOL;
+                        echo "\t* first token on line $line is $type *".PHP_EOL;
                     }
-                }
 
-                // Don't force current indent to divisible because there could be custom
-                // rules in place between parenthesis, such as with arrays.
-                $currentIndent = ($tokens[$first]['column'] - 1);
-                if (isset($adjustments[$first]) === true) {
-                    $currentIndent += $adjustments[$first];
-                }
+                    if ($first === $tokens[$parenCloser]['parenthesis_opener']) {
+                        // This is unlikely to be the start of the statement, so look
+                        // back further to find it.
+                        $first--;
+                    }
 
-                if ($this->_debug === true) {
-                    echo "\t=> checking indent of $checkIndent; main indent set to $currentIndent".PHP_EOL;
-                }
+                    $prev = $phpcsFile->findStartOfStatement($first);
+                    if ($prev !== $first) {
+                        // This is not the start of the statement.
+                        if ($this->_debug === true) {
+                            $line = $tokens[$prev]['line'];
+                            $type = $tokens[$prev]['type'];
+                            echo "\t* previous is $type on line $line *".PHP_EOL;
+                        }
+
+                        $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                        $prev  = $phpcsFile->findStartOfStatement($first);
+                        $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                        if ($this->_debug === true) {
+                            $line = $tokens[$first]['line'];
+                            $type = $tokens[$first]['type'];
+                            echo "\t* amended first token is $type on line $line *".PHP_EOL;
+                        }
+                    }
+
+                    if (isset($tokens[$first]['scope_closer']) === true
+                        && $tokens[$first]['scope_closer'] === $first
+                    ) {
+                        if ($this->_debug === true) {
+                            echo "\t* first token is a scope closer *".PHP_EOL;
+                        }
+
+                        if (isset($tokens[$first]['scope_condition']) === true) {
+                            $scopeCloser = $first;
+                            $first       = $phpcsFile->findFirstOnLine(T_WHITESPACE, $tokens[$scopeCloser]['scope_condition'], true);
+
+                            $currentIndent = ($tokens[$first]['column'] - 1);
+                            if (isset($adjustments[$first]) === true) {
+                                $currentIndent += $adjustments[$first];
+                            }
+
+                            // Make sure it is divisible by our expected indent.
+                            if ($tokens[$tokens[$scopeCloser]['scope_condition']]['code'] !== T_CLOSURE) {
+                                $currentIndent = (int) (ceil($currentIndent / $this->indent) * $this->indent);
+                            }
+
+                            if ($this->_debug === true) {
+                                echo "\t=> indent set to $currentIndent".PHP_EOL;
+                            }
+                        }//end if
+                    } else {
+                        // Don't force current indent to divisible because there could be custom
+                        // rules in place between parenthesis, such as with arrays.
+                        $currentIndent = ($tokens[$first]['column'] - 1);
+                        if (isset($adjustments[$first]) === true) {
+                            $currentIndent += $adjustments[$first];
+                        }
+
+                        if ($this->_debug === true) {
+                            echo "\t=> checking indent of $checkIndent; main indent set to $currentIndent".PHP_EOL;
+                        }
+                    }//end if
+                } else if ($this->_debug === true) {
+                    echo "\t * ignoring single-line definition *".PHP_EOL;
+                }//end if
             }//end if
 
-            // Closing parenthesis should just be indented to at least
-            // the same level as where they were opened (but can be more).
-            if ($checkToken !== null
-                && $tokens[$checkToken]['code'] === T_CLOSE_SHORT_ARRAY
+            // Closing short array bracket should just be indented to at least
+            // the same level as where it was opened (but can be more).
+            if ($tokens[$i]['code'] === T_CLOSE_SHORT_ARRAY
+                || ($checkToken !== null
+                && $tokens[$checkToken]['code'] === T_CLOSE_SHORT_ARRAY)
             ) {
+                if ($checkToken !== null) {
+                    $arrayCloser = $checkToken;
+                } else {
+                    $arrayCloser = $i;
+                }
+
                 if ($this->_debug === true) {
-                    $line = $tokens[$i]['line'];
+                    $line = $tokens[$arrayCloser]['line'];
                     echo "Closing short array bracket found on line $line".PHP_EOL;
                 }
 
-                $first       = $phpcsFile->findFirstOnLine(T_WHITESPACE, $tokens[$checkToken]['bracket_opener'], true);
-                $checkIndent = ($tokens[$first]['column'] - 1);
-                if (isset($adjustments[$first]) === true) {
-                    $checkIndent += $adjustments[$first];
-                }
-
-                $exact = false;
-
-                if ($this->_debug === true) {
-                    $line = $tokens[$first]['line'];
-                    $type = $tokens[$first]['type'];
-                    echo "\t* first token on line $line is $type *".PHP_EOL;
-                }
-
-                $prev = $phpcsFile->findStartOfStatement($first);
-                if ($prev !== $first) {
-                    // This is not the start of the statement.
-                    if ($this->_debug === true) {
-                        $line = $tokens[$prev]['line'];
-                        $type = $tokens[$prev]['type'];
-                        echo "\t* previous is $type on line $line *".PHP_EOL;
+                $arrayOpener = $tokens[$arrayCloser]['bracket_opener'];
+                if ($tokens[$arrayCloser]['line'] !== $tokens[$arrayOpener]['line']) {
+                    $first       = $phpcsFile->findFirstOnLine(T_WHITESPACE, $arrayOpener, true);
+                    $checkIndent = ($tokens[$first]['column'] - 1);
+                    if (isset($adjustments[$first]) === true) {
+                        $checkIndent += $adjustments[$first];
                     }
 
-                    $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
-                    $prev  = $phpcsFile->findStartOfStatement($first);
-                    $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                    $exact = false;
+
                     if ($this->_debug === true) {
                         $line = $tokens[$first]['line'];
                         $type = $tokens[$first]['type'];
-                        echo "\t* amended first token is $type on line $line *".PHP_EOL;
+                        echo "\t* first token on line $line is $type *".PHP_EOL;
                     }
-                }
 
-                // Don't force current indent to be divisible because there could be custom
-                // rules in place for arrays.
-                $currentIndent = ($tokens[$first]['column'] - 1);
-                if (isset($adjustments[$first]) === true) {
-                    $currentIndent += $adjustments[$first];
-                }
+                    if ($first === $tokens[$arrayCloser]['bracket_opener']) {
+                        // This is unlikely to be the start of the statement, so look
+                        // back further to find it.
+                        $first--;
+                    }
 
-                if ($this->_debug === true) {
-                    echo "\t=> checking indent of $checkIndent; main indent set to $currentIndent".PHP_EOL;
-                }
+                    $prev = $phpcsFile->findStartOfStatement($first);
+                    if ($prev !== $first) {
+                        // This is not the start of the statement.
+                        if ($this->_debug === true) {
+                            $line = $tokens[$prev]['line'];
+                            $type = $tokens[$prev]['type'];
+                            echo "\t* previous is $type on line $line *".PHP_EOL;
+                        }
+
+                        $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                        $prev  = $phpcsFile->findStartOfStatement($first);
+                        $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $prev, true);
+                        if ($this->_debug === true) {
+                            $line = $tokens[$first]['line'];
+                            $type = $tokens[$first]['type'];
+                            echo "\t* amended first token is $type on line $line *".PHP_EOL;
+                        }
+                    }
+
+                    if (isset($tokens[$first]['scope_closer']) === true
+                        && $tokens[$first]['scope_closer'] === $first
+                    ) {
+                        // The first token is a scope closer and would have already
+                        // been processed and set the indent level correctly, so
+                        // don't adjust it again.
+                        if ($this->_debug === true) {
+                            echo "\t* first token is a scope closer; ignoring closing short array bracket *".PHP_EOL;
+                        }
+                    } else {
+                        // Don't force current indent to be divisible because there could be custom
+                        // rules in place for arrays.
+                        $currentIndent = ($tokens[$first]['column'] - 1);
+                        if (isset($adjustments[$first]) === true) {
+                            $currentIndent += $adjustments[$first];
+                        }
+
+                        if ($this->_debug === true) {
+                            echo "\t=> checking indent of $checkIndent; main indent set to $currentIndent".PHP_EOL;
+                        }
+                    }
+                } else if ($this->_debug === true) {
+                    echo "\t * ignoring single-line definition *".PHP_EOL;
+                }//end if
             }//end if
 
             // Adjust lines within scopes while auto-fixing.
@@ -414,29 +507,31 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                     array_pop($openScopes);
                 }
 
-                $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $tokens[$scopeCloser]['scope_condition'], true);
+                if (isset($tokens[$scopeCloser]['scope_condition']) === true) {
+                    $first = $phpcsFile->findFirstOnLine(T_WHITESPACE, $tokens[$scopeCloser]['scope_condition'], true);
 
-                $currentIndent = ($tokens[$first]['column'] - 1);
-                if (isset($adjustments[$first]) === true) {
-                    $currentIndent += $adjustments[$first];
-                }
+                    $currentIndent = ($tokens[$first]['column'] - 1);
+                    if (isset($adjustments[$first]) === true) {
+                        $currentIndent += $adjustments[$first];
+                    }
 
-                // Make sure it is divisible by our expected indent.
-                if ($tokens[$tokens[$scopeCloser]['scope_condition']]['code'] !== T_CLOSURE) {
-                    $currentIndent = (int) (ceil($currentIndent / $this->indent) * $this->indent);
-                }
+                    // Make sure it is divisible by our expected indent.
+                    if ($tokens[$tokens[$scopeCloser]['scope_condition']]['code'] !== T_CLOSURE) {
+                        $currentIndent = (int) (ceil($currentIndent / $this->indent) * $this->indent);
+                    }
 
-                if ($this->_debug === true) {
-                    echo "\t=> indent set to $currentIndent".PHP_EOL;
-                }
+                    if ($this->_debug === true) {
+                        echo "\t=> indent set to $currentIndent".PHP_EOL;
+                    }
 
-                // We only check the indent of scope closers if they are
-                // curly braces because other constructs tend to have different rules.
-                if ($tokens[$scopeCloser]['code'] === T_CLOSE_CURLY_BRACKET) {
-                    $exact = true;
-                } else {
-                    $checkToken = null;
-                }
+                    // We only check the indent of scope closers if they are
+                    // curly braces because other constructs tend to have different rules.
+                    if ($tokens[$scopeCloser]['code'] === T_CLOSE_CURLY_BRACKET) {
+                        $exact = true;
+                    } else {
+                        $checkToken = null;
+                    }
+                }//end if
             }//end if
 
             // Handle scope for JS object notation.
@@ -583,6 +678,15 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                 }
             }//end if
 
+            // Method prefix indentation has to be exact or else if will break
+            // the rest of the function declaration, and potentially future ones.
+            if ($checkToken !== null
+                && isset(PHP_CodeSniffer_Tokens::$methodPrefixes[$tokens[$checkToken]['code']]) === true
+                && $tokens[($checkToken + 1)]['code'] !== T_DOUBLE_COLON
+            ) {
+                $exact = true;
+            }
+
             // JS property indentation has to be exact or else if will break
             // things like function and object indentation.
             if ($checkToken !== null && $tokens[$checkToken]['code'] === T_PROPERTY) {
@@ -997,11 +1101,20 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                 }
 
                 $currentIndent = ($tokens[$first]['column'] - 1);
-
                 if ($object > 0 || $condition > 0) {
                     $currentIndent += $this->indent;
                 }
 
+                if (isset($tokens[$first]['scope_closer']) === true
+                    && $tokens[$first]['scope_closer'] === $first
+                ) {
+                    if ($this->_debug === true) {
+                        echo "\t* first token is a scope closer *".PHP_EOL;
+                    }
+
+                    $currentIndent -= $this->indent;
+                }
+
                 // Make sure it is divisible by our expected indent.
                 $currentIndent = (int) (ceil($currentIndent / $this->indent) * $this->indent);
 
