@@ -17,3 +17,9 @@ while (something) print 'hello';
 do {
     i--;
 } while (something);
+
+do i++; while (i < 5);
+
+SomeClass.prototype.switch = function() {
+    // do something
+};
