@@ -1,4 +1,4 @@
-<?php
+
 
 // Valid
 var1    = 'var1';
@@ -34,7 +34,7 @@ var1000 += 'var1';
 
 // Invalid
 var1    += 'var1';
-var10 += 'var1';
+var10+= 'var1';
 var100 += 'var1';
 var1000 += 'var1';
 
@@ -48,7 +48,7 @@ var1000 += 'var1';
 var1    = 'var1';
 var10   += 'var1';
 var100  = 'var1';
-var1000 += 'var1';
+var1000+= 'var1';
 
 // Valid
 var1  += 'var1';
@@ -84,4 +84,21 @@ var spinButtonid = [this.id, '-positionFormats-spinButton'].join('');
 var spinButtonWidget = WidgetStore.get(spinButtonid);
 var position = spinButtonWidget.getValue();
 var posForamatsList = WidgetStore.get([self.id, '-positionFormats-list'].join(''));
-?>
+
+dfx.stripTags = function(content, allowedTags)
+{
+    var match;
+    var re = 'blah';
+};
+
+var contents  += 'if (';
+var conditions = array();
+
+var foo  = {};
+foo.blah = 'blah';
+
+var script = document.createElement('script');
+script.onload = function()
+{
+    clearTimeout(t);
+};
