@@ -23,7 +23,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_NamingConventions_CamelCapsFunctionNameUnitTest extends AbstractSniffUnitTest
@@ -41,46 +41,41 @@ class Generic_Tests_NamingConventions_CamelCapsFunctionNameUnitTest extends Abst
     public function getErrorList()
     {
         $errors = array(
-                   10 => 1,
-                   11 => 1,
-                   12 => 1,
-                   13 => 1,
-                   16 => 1,
-                   17 => 1,
-                   20 => 1,
-                   21 => 1,
-                   24 => 1,
-                   25 => 1,
-                   30 => 1,
-                   31 => 1,
-                   50 => 1,
-                   52 => 1,
-                   53 => 1,
-                   57 => 1,
-                   58 => 1,
-                   59 => 1,
-                   60 => 1,
-                   61 => 1,
-                   62 => 1,
-                   63 => 1,
-                   64 => 1,
-                   65 => 1,
-                   66 => 1,
-                   67 => 1,
-                   68 => 1,
-                   69 => 1,
-                   71 => 1,
-                   72 => 1,
-                   73 => 1,
-                   74 => 1,
+                   10  => 1,
+                   11  => 1,
+                   12  => 1,
+                   13  => 1,
+                   16  => 1,
+                   17  => 1,
+                   20  => 1,
+                   21  => 1,
+                   24  => 1,
+                   25  => 1,
+                   30  => 1,
+                   31  => 1,
+                   50  => 1,
+                   52  => 1,
+                   53  => 1,
+                   57  => 1,
+                   58  => 1,
+                   59  => 1,
+                   60  => 1,
+                   61  => 1,
+                   62  => 1,
+                   63  => 1,
+                   64  => 1,
+                   65  => 1,
+                   66  => 1,
+                   67  => 1,
+                   68  => 1,
+                   69  => 1,
+                   71  => 1,
+                   72  => 1,
+                   73  => 1,
+                   74  => 1,
+                   118 => 1,
                   );
 
-        // The trait tests will only work in PHP version where traits exist and
-        // will throw errors in earlier versions.
-        if (version_compare(PHP_VERSION, '5.4.0') < 0) {
-            $errors[95] = 1;
-        }
-
         return $errors;
 
     }//end getErrorList()
