@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
@@ -102,7 +102,7 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
                 $error = 'Block comments must be ended with */';
                 $fix   = $phpcsFile->addFixableError($error, $end, 'WrongEnd');
                 if ($fix === true) {
-                    $phpcsFile->fixer->replaceToken($stackPtr, '*/');
+                    $phpcsFile->fixer->replaceToken($end, '*/');
                 }
             }
 
@@ -214,7 +214,7 @@ class Squiz_Sniffs_Commenting_BlockCommentSniff implements PHP_CodeSniffer_Sniff
                 }
             }
 
-            if (preg_match('/\p{Lu}|\P{L}/u', $commentText[0]) === 0) {
+            if (preg_match('/^\p{Ll}/u', $commentText) === 1) {
                 $error = 'Block comments must start with a capital letter';
                 $phpcsFile->addError($error, $commentLines[1], 'NoCapital');
             }
