@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -76,7 +76,13 @@ class Squiz_Sniffs_ControlStructures_ForEachLoopDeclarationSniff implements PHP_
         $openingBracket = $phpcsFile->findNext(T_OPEN_PARENTHESIS, $stackPtr);
         if ($openingBracket === false) {
             $error = 'Possible parse error: FOREACH has no opening parenthesis';
-            $phpcsFile->addWarning($error, $stackPtr, 'MissingParenthesis');
+            $phpcsFile->addWarning($error, $stackPtr, 'MissingOpenParenthesis');
+            return;
+        }
+
+        if (isset($tokens[$openingBracket]['parenthesis_closer']) === false) {
+            $error = 'Possible parse error: FOREACH has no closing parenthesis';
+            $phpcsFile->addWarning($error, $stackPtr, 'MissingCloseParenthesis');
             return;
         }
 
