@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -78,11 +78,20 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
+        $tokens = $phpcsFile->getTokens();
+
+        if (isset($tokens[$stackPtr]['parenthesis_opener']) === false
+            || isset($tokens[$stackPtr]['parenthesis_closer']) === false
+            || $tokens[$stackPtr]['parenthesis_opener'] === null
+            || $tokens[$stackPtr]['parenthesis_closer'] === null
+        ) {
+            return;
+        }
+
         $this->equalsSpacing           = (int) $this->equalsSpacing;
         $this->requiredSpacesAfterOpen = (int) $this->requiredSpacesAfterOpen;
         $this->requiredSpacesBeforeClose = (int) $this->requiredSpacesBeforeClose;
 
-        $tokens      = $phpcsFile->getTokens();
         $openBracket = $tokens[$stackPtr]['parenthesis_opener'];
         $this->processBracket($phpcsFile, $openBracket);
 
@@ -312,11 +321,11 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
                     }
 
                     $spaceAfterOpen = 0;
-                    if ($multiLine === false && $tokens[($bracket + 1)]['code'] === T_WHITESPACE) {
+                    if ($tokens[($bracket + 1)]['code'] === T_WHITESPACE) {
                         $spaceAfterOpen = strlen($tokens[($bracket + 1)]['content']);
                     }
 
-                    if ($spaceAfterOpen !== $this->requiredSpacesAfterOpen) {
+                    if ($multiLine === false && $spaceAfterOpen !== $this->requiredSpacesAfterOpen) {
                         $error = 'Expected %s spaces between opening bracket and type hint "%s"; %s found';
                         $data  = array(
                                   $this->requiredSpacesAfterOpen,
