@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Sniff
@@ -103,6 +103,13 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
 
         $allowedChars = array(
                          '\0',
+                         '\1',
+                         '\2',
+                         '\3',
+                         '\4',
+                         '\5',
+                         '\6',
+                         '\7',
                          '\n',
                          '\r',
                          '\f',
@@ -110,6 +117,8 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
                          '\v',
                          '\x',
                          '\b',
+                         '\e',
+                         '\u',
                          '\'',
                         );
 
