@@ -22,7 +22,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Commenting_FunctionCommentUnitTest extends AbstractSniffUnitTest
@@ -109,6 +109,8 @@ class Squiz_Tests_Commenting_FunctionCommentUnitTest extends AbstractSniffUnitTe
                    548 => 1,
                    641 => 1,
                    669 => 1,
+                   744 => 1,
+                   748 => 1,
                   );
 
         // The yield tests will only work in PHP versions where yield exists and
@@ -119,6 +121,22 @@ class Squiz_Tests_Commenting_FunctionCommentUnitTest extends AbstractSniffUnitTe
             $errors[688] = 1;
         }
 
+        // Scalar type hints only work from PHP 7 onwards.
+        if (version_compare(PHP_VERSION, '7.0.0') >= 0) {
+            $errors[17]  = 1;
+            $errors[143] = 3;
+            $errors[161] = 2;
+            $errors[201] = 1;
+            $errors[363] = 3;
+            $errors[377] = 1;
+            $errors[575] = 2;
+            $errors[627] = 1;
+        } else {
+            $errors[729] = 4;
+            $errors[740] = 2;
+            $errors[752] = 2;
+        }
+
         return $errors;
 
     }//end getErrorList()
