@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Commenting_InlineCommentUnitTest extends AbstractSniffUnitTest
@@ -59,16 +59,10 @@ class Squiz_Tests_Commenting_InlineCommentUnitTest extends AbstractSniffUnitTest
                        67  => 1,
                        95  => 1,
                        96  => 1,
-                       97  => 2,
+                       97  => 3,
                        118 => 1,
                       );
 
-            // The trait tests will only work in PHP version where traits exist and
-            // will throw errors in earlier versions.
-            if (version_compare(PHP_VERSION, '5.4.0') < 0) {
-                $errors[106] = 1;
-            }
-
             return $errors;
         case 'InlineCommentUnitTest.js':
             return array(
