@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Files_FileExtensionUnitTest extends AbstractSniffUnitTest
@@ -49,13 +49,6 @@ class Squiz_Tests_Files_FileExtensionUnitTest extends AbstractSniffUnitTest
             return array(
                     1 => 1,
                    );
-        case 'FileExtensionUnitTest.4.inc':
-            if (version_compare(PHP_VERSION, '5.4.0', '<') === true) {
-                // Traits are available from PHP 5.4.0.
-                return array(
-                        1 => 1,
-                       );
-            }
         default:
             return array();
         }
