@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_NamingConventions_ValidVariableNameUnitTest extends AbstractSniffUnitTest
@@ -73,11 +73,6 @@ class Squiz_Tests_NamingConventions_ValidVariableNameUnitTest extends AbstractSn
                    117 => 1,
                   );
 
-        // The trait test will only work in PHP versions where traits exist.
-        if (version_compare(PHP_VERSION, '5.4.0') < 0) {
-            $errors[118] = 1;
-        }
-
         return $errors;
 
     }//end getErrorList()
