@@ -54,3 +54,38 @@ switch (result) {
 
 result = x?y:z;
 result = x ? y : z;
+
+if (something === true
+    ^ somethingElse === true
+) {
+    return false;
+}
+
+y = 1
+  + 2  
+  - 3;
+
+y = 1 + 
+    2 - 
+    3;
+
+y = 1
++ 2
+- 3;
+
+// @codingStandardsChangeSetting Squiz.WhiteSpace.OperatorSpacing ignoreNewlines true
+y = 1
+  + 2
+  - 3;
+
+y = 1 +
+    2 -
+    3;
+
+y = 1
++ 2
+- 3;
+// @codingStandardsChangeSetting Squiz.WhiteSpace.OperatorSpacing ignoreNewlines false
+
+if (true || -1 == b) {
+}
