@@ -24,7 +24,7 @@ if (class_exists('PHP_CodeSniffer_Tokenizers_PHP', true) === false) {
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
@@ -44,7 +44,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
     public function tokenizeString($string, $eolChar='\n')
     {
         if (PHP_CODESNIFFER_VERBOSITY > 1) {
-            echo "\t*** START CSS TOKENIZING ***".PHP_EOL;
+            echo "\t*** START CSS TOKENIZING 1ST PASS ***".PHP_EOL;
         }
 
         // If the content doesn't have an EOL char on the end, add one so
@@ -78,6 +78,10 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
             if ($token['code'] === T_BREAK
                 || $token['code'] === T_LIST
                 || $token['code'] === T_DEFAULT
+                || $token['code'] === T_SWITCH
+                || $token['code'] === T_FOR
+                || $token['code'] === T_FOREACH
+                || $token['code'] === T_WHILE
             ) {
                 $token['type'] = 'T_STRING';
                 $token['code'] = T_STRING;
@@ -89,12 +93,12 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 echo "\tProcess token $stackPtr: $type => $content".PHP_EOL;
             }
 
-            if ($token['code'] === T_POWER
+            if ($token['code'] === T_BITWISE_XOR
                 && $tokens[($stackPtr + 1)]['content'] === 'PHPCS_CSS_T_OPEN_TAG'
             ) {
                 $content = '<?php';
                 for ($stackPtr = ($stackPtr + 3); $stackPtr < $numTokens; $stackPtr++) {
-                    if ($tokens[$stackPtr]['code'] === T_POWER
+                    if ($tokens[$stackPtr]['code'] === T_BITWISE_XOR
                         && $tokens[($stackPtr + 1)]['content'] === 'PHPCS_CSS_T_CLOSE_TAG'
                     ) {
                         // Add the end tag and ignore the * we put at the end.
@@ -172,7 +176,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 $leadingZero = false;
                 if ($content{0} === '0') {
                     $content     = '1'.$content;
-                    $leadingZero = false;
+                    $leadingZero = true;
                 }
 
                 $commentTokens = parent::tokenizeString('<?php '.$content.'?>', $eolChar);
@@ -231,22 +235,9 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
 
                 $newStackPtr++;
 
-                foreach ($commentTokens as $tokenData) {
-                    if ($tokenData['code'] === T_COMMENT
-                        && (substr($tokenData['content'], 0, 2) === '//'
-                        || $tokenData['content']{0} === '#')
-                    ) {
-                        // This is a comment in a comment, so it needs
-                        // to go through the whole process again.
-                        $tokens[$stackPtr]['content'] = $tokenData['content'];
-                        $stackPtr--;
-                        break;
-                    }
-
-                    $finalTokens[$newStackPtr] = $tokenData;
-                    $newStackPtr++;
-                }
-
+                array_splice($tokens, $stackPtr, 1, $commentTokens);
+                $numTokens = count($tokens);
+                $stackPtr--;
                 continue;
             }//end if
 
@@ -261,6 +252,11 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
             $newStackPtr++;
         }//end for
 
+        if (PHP_CODESNIFFER_VERBOSITY > 1) {
+            echo "\t*** END CSS TOKENIZING 1ST PASS ***".PHP_EOL;
+            echo "\t*** START CSS TOKENIZING 2ND PASS ***".PHP_EOL;
+        }
+
         // A flag to indicate if we are inside a style definition,
         // which is defined using curly braces.
         $inStyleDef = false;
@@ -273,6 +269,12 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
         for ($stackPtr = 0; $stackPtr < $numTokens; $stackPtr++) {
             $token = $finalTokens[$stackPtr];
 
+            if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                $type    = $token['type'];
+                $content = PHP_CodeSniffer::prepareForOutput($token['content']);
+                echo "\tProcess token $stackPtr: $type => $content".PHP_EOL;
+            }
+
             switch ($token['code']) {
             case T_OPEN_CURLY_BRACKET:
                 // Opening curly brackets for an At-rule do not start a style
@@ -280,13 +282,36 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                 // opening curly bracket could be indeed the start of a style
                 // definition.
                 if ($asperandStart === true) {
+                    if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                        if ($inStyleDef === true) {
+                            echo "\t\t* style definition closed *".PHP_EOL;
+                        }
+
+                        if ($asperandStart === true) {
+                            echo "\t\t* at-rule definition closed *".PHP_EOL;
+                        }
+                    }
+
                     $inStyleDef    = false;
                     $asperandStart = false;
                 } else {
                     $inStyleDef = true;
+                    if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                        echo "\t\t* style definition opened *".PHP_EOL;
+                    }
                 }
                 break;
             case T_CLOSE_CURLY_BRACKET:
+                if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                    if ($inStyleDef === true) {
+                        echo "\t\t* style definition closed *".PHP_EOL;
+                    }
+
+                    if ($asperandStart === true) {
+                        echo "\t\t* at-rule definition closed *".PHP_EOL;
+                    }
+                }
+
                 $inStyleDef    = false;
                 $asperandStart = false;
                 break;
@@ -297,6 +322,13 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                     if ($finalTokens[($stackPtr - 1)]['code'] === T_STRING) {
                         $newContent = $finalTokens[($stackPtr - 1)]['content'].'-'.$finalTokens[($stackPtr + 1)]['content'];
 
+                        if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                            echo "\t\t* token is a string joiner; ignoring this and previous token".PHP_EOL;
+                            $old = PHP_CodeSniffer::prepareForOutput($finalTokens[($stackPtr + 1)]['content']);
+                            $new = PHP_CodeSniffer::prepareForOutput($newContent);
+                            echo "\t\t=> token ".($stackPtr + 1)." content changed from \"$old\" to \"$new\"".PHP_EOL;
+                        }
+
                         $finalTokens[($stackPtr + 1)]['content'] = $newContent;
                         unset($finalTokens[$stackPtr]);
                         unset($finalTokens[($stackPtr - 1)]);
@@ -308,8 +340,13 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                     }
                 } else if ($finalTokens[($stackPtr + 1)]['code'] === T_LNUMBER) {
                     // They can also be used to provide negative numbers.
-                    $finalTokens[($stackPtr + 1)]['content']
-                        = '-'.$finalTokens[($stackPtr + 1)]['content'];
+                    if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                        echo "\t\t* token is part of a negative number; adding content to next token and ignoring *".PHP_EOL;
+                        $content = PHP_CodeSniffer::prepareForOutput($finalTokens[($stackPtr + 1)]['content']);
+                        echo "\t\t=> token ".($stackPtr + 1)." content changed from \"$content\" to \"-$content\"".PHP_EOL;
+                    }
+
+                    $finalTokens[($stackPtr + 1)]['content'] = '-'.$finalTokens[($stackPtr + 1)]['content'];
                     unset($finalTokens[$stackPtr]);
                 }//end if
 
@@ -326,6 +363,11 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                     }
                 }
 
+                if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                    $type = $finalTokens[$x]['type'];
+                    echo "\t\t=> token $x changed from $type to T_STYLE".PHP_EOL;
+                }
+
                 $finalTokens[$x]['type'] = 'T_STYLE';
                 $finalTokens[$x]['code'] = T_STYLE;
                 break;
@@ -354,6 +396,16 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                         continue;
                     }
 
+                    if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                        for ($i = ($stackPtr + 1); $i <= $y; $i++) {
+                            $type    = $finalTokens[$i]['type'];
+                            $content = PHP_CodeSniffer::prepareForOutput($finalTokens[$i]['content']);
+                            echo "\tProcess token $i: $type => $content".PHP_EOL;
+                        }
+
+                        echo "\t\t* token starts a URL *".PHP_EOL;
+                    }
+
                     // Join all the content together inside the url() statement.
                     $newContent = '';
                     for ($i = ($x + 2); $i < $numTokens; $i++) {
@@ -362,9 +414,16 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
                         }
 
                         $newContent .= $finalTokens[$i]['content'];
+                        if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                            $content = PHP_CodeSniffer::prepareForOutput($finalTokens[$i]['content']);
+                            echo "\t\t=> token $i added to URL string and ignored: $content".PHP_EOL;
+                        }
+
                         unset($finalTokens[$i]);
                     }
 
+                    $stackPtr = $i;
+
                     // If the content inside the "url()" is in double quotes
                     // there will only be one token and so we don't have to do
                     // anything except change its type. If it is not empty,
@@ -374,15 +433,19 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
 
                     if ($newContent !== '') {
                         $finalTokens[($x + 1)]['content'] .= $newContent;
-
-                        $finalTokens = array_values($finalTokens);
-                        $numTokens   = count($finalTokens);
+                        if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                            $content = PHP_CodeSniffer::prepareForOutput($finalTokens[($x + 1)]['content']);
+                            echo "\t\t=> token content changed to: $content".PHP_EOL;
+                        }
                     }
                 }//end if
 
                 break;
             case T_ASPERAND:
                 $asperandStart = true;
+                if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                    echo "\t\t* at-rule definition opened *".PHP_EOL;
+                }
                 break;
             default:
                 // Nothing special to be done with this token.
@@ -413,7 +476,7 @@ class PHP_CodeSniffer_Tokenizers_CSS extends PHP_CodeSniffer_Tokenizers_PHP
         }
 
         if (PHP_CODESNIFFER_VERBOSITY > 1) {
-            echo "\t*** END CSS TOKENIZING ***".PHP_EOL;
+            echo "\t*** END CSS TOKENIZING 2ND PASS ***".PHP_EOL;
         }
 
         return $finalTokens;
