@@ -21,7 +21,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.3.3
+ * @version   Release: 2.5.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Tokenizers_JS
@@ -421,7 +421,7 @@ class PHP_CodeSniffer_Tokenizers_JS
 
             // Special case for T_DIVIDE which can actually be
             // the start of a regular expression.
-            if ($buffer === $char && $char === '/') {
+            if ($buffer === $char && $char === '/' && $chars[($i + 1)] !== '*') {
                 $regex = $this->getRegexToken(
                     $i,
                     $string,
@@ -676,6 +676,7 @@ class PHP_CodeSniffer_Tokenizers_JS
                 $cleanBuffer = false;
             }
         }//end for
+
         if (empty($buffer) === false) {
             // Buffer contains whitespace from the end of the file.
             $tokens[] = array(
@@ -735,7 +736,9 @@ class PHP_CodeSniffer_Tokenizers_JS
 
                         // If the substr failed, skip the token as the content
                         // will now be blank.
-                        if ($tokens[$stackPtr]['content'] !== false) {
+                        if ($tokens[$stackPtr]['content'] !== false
+                            && $tokens[$stackPtr]['content'] !== ''
+                        ) {
                             $stackPtr--;
                         }
 
@@ -825,6 +828,25 @@ class PHP_CodeSniffer_Tokenizers_JS
                     $stackPtr = $oldStackPtr;
                 }
             }//end if
+
+            // Convert the token after an object operator into a string, in most cases.
+            if ($token['code'] === T_OBJECT_OPERATOR) {
+                for ($i = ($stackPtr + 1); $i < $numTokens; $i++) {
+                    if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$tokens[$i]['code']]) === true) {
+                        continue;
+                    }
+
+                    if ($tokens[$i]['code'] !== T_PROTOTYPE
+                        && $tokens[$i]['code'] !== T_LNUMBER
+                        && $tokens[$i]['code'] !== T_DNUMBER
+                    ) {
+                        $tokens[$i]['code'] = T_STRING;
+                        $tokens[$i]['type'] = 'T_STRING';
+                    }
+
+                    break;
+                }
+            }
         }//end for
 
         if (PHP_CODESNIFFER_VERBOSITY > 1) {
